// @ts-check
import { defineConfig, envField } from "astro/config"
import tailwindcss from "@tailwindcss/vite"
import sitemap from "@astrojs/sitemap"
import svelte from "@astrojs/svelte"
import node from "@astrojs/node"
import mdx from "@astrojs/mdx"
import icon from "astro-icon"

import { loadEnv } from "vite"
import { paraglideVitePlugin } from "@inlang/paraglide-js"

const { URL } = process.env.NODE_ENV
  ? loadEnv(process.env.NODE_ENV, process.cwd(), "")
  : { URL: "http://localhost:3000" }

// https://astro.build/config
export default defineConfig({
  site: URL,
  output: "server",
  i18n: {
    defaultLocale: "nb",
    locales: ["nb", "en"]
  },
  integrations: [
    sitemap(),
    mdx(),
    svelte(),
    icon()
  ],
  adapter: node({
    mode: "standalone"
  }),
  vite: {
    plugins: [
      tailwindcss(),
      paraglideVitePlugin({
        project: "./project.inlang",
        outdir: "./src/paraglide"
      })
    ]
  },
  markdown: {
    shikiConfig: {
      theme: "catppuccin-mocha"
    }
  },
  env: {
    schema: {
      DOMAIN: envField.string({ context: "client", access: "public" }),
      URL: envField.string({ context: "client", access: "public" }),
      GIT_URL: envField.string({ context: "client", access: "public" }),
      STATUS_URL: envField.string({ context: "client", access: "public" })
    }
  }
})
